@@ -119,6 +119,8 @@ class BasicTarget(object):
                 fpath = os.path.join(root, fname)
                 name = self.unprefix_path(fpath)
                 if fname.endswith('.json'):
+                    if os.path.basename(fpath) == 'package.json':
+                        continue
                     with open(fpath, 'rb') as fhl:
                         data = fhl.read()
                         info = json.loads(data)
@@ -278,6 +280,8 @@ class ExtensionsTarget(BasicTarget):
             return inx.ident
         except UnrecognizedArchiveFormat:
             raise IOError("Refusing the install extension without inx file (unknown archive)")
+        except:
+            raise IOError("Refusing the install extension with bad inx file!")
 
     def _list_installed(self):
         """
